@@ -2,7 +2,8 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 2003, 2004 and 2005 by the Free Software Foundation.    *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
+ * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
@@ -248,7 +249,7 @@ break_in_goal_from_str(int str, signed char goal[BOARDMAX],
     /* Successful break-in/unsuccessful block. Now where exactly can we
      * erase territory? This is difficult, and the method here is very
      * crude: Wherever we enter the territory when computing the closest
-     * neighbors of (str). Plus at the locaction of the break-in move.
+     * neighbors of (str). Plus at the location of the break-in move.
      * FIXME: This needs improvement.
      */
     int k;
@@ -258,10 +259,11 @@ break_in_goal_from_str(int str, signed char goal[BOARDMAX],
     if (ON_BOARD(move) && goal[move]) {
       non_territory[(*num_non_territory)++] = move;
       if (info_pos)
-	DEBUG(DEBUG_TERRITORY, "%1m: Erasing territory at %1m -a.\n",
-	      info_pos, move);
+	DEBUG(DEBUG_TERRITORY | DEBUG_BREAKIN,
+	      "%1m: Erasing territory at %1m -a.\n", info_pos, move);
       else
-	DEBUG(DEBUG_TERRITORY, "Erasing territory at %1m -a.\n", move);
+	DEBUG(DEBUG_TERRITORY | DEBUG_BREAKIN,
+	      "Erasing territory at %1m -a.\n", move);
     }
 
     for (k = 0; k < conn.queue_end; k++) {
@@ -273,10 +275,11 @@ break_in_goal_from_str(int str, signed char goal[BOARDMAX],
 	      || !goal[conn.coming_from[pos]])) {
 	non_territory[(*num_non_territory)++] = pos;
 	if (info_pos)
-	  DEBUG(DEBUG_TERRITORY, "%1m: Erasing territory at %1m -b.\n",
-		info_pos, pos);
+	  DEBUG(DEBUG_TERRITORY | DEBUG_BREAKIN,
+		"%1m: Erasing territory at %1m -b.\n", info_pos, pos);
 	else
-	  DEBUG(DEBUG_TERRITORY, "Erasing territory at %1m -b.\n", pos);
+	  DEBUG(DEBUG_TERRITORY | DEBUG_BREAKIN,
+	        "Erasing territory at %1m -b.\n", pos);
 	if (conn.distances[pos] < cut_off_distance)
 	  cut_off_distance = conn.distances[pos];
       }
@@ -411,7 +414,7 @@ break_territories(int color_to_move, struct influence_data *q, int store,
   struct moyo_data territories;
   int k;
 
-  if (!experimental_break_in || level < 10)
+  if (!experimental_break_in || get_level() < 10)
     return;
 
   influence_get_territory_segmentation(q, &territories);
