@@ -2,7 +2,7 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004 and 2005             *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
@@ -83,7 +83,9 @@ calculate_hashval_for_tt(Hash_data *hashdata, int routine, int target1,
 
 
 
-/* Initialize the transposition table. */
+/* Initialize the transposition table. Non-positive memsize means use
+ * the default size of DEFAULT_NUMBER_OF_CACHE_ENTRIES entries.
+ */
 
 static void
 tt_init(Transposition_table *table, int memsize)
@@ -94,7 +96,10 @@ tt_init(Transposition_table *table, int memsize)
   hash_init();
   keyhash_init();
 
-  num_entries = memsize / sizeof(table->entries[0]);
+  if (memsize > 0)
+    num_entries = memsize / sizeof(table->entries[0]);
+  else
+    num_entries = DEFAULT_NUMBER_OF_CACHE_ENTRIES;
 
   table->num_entries = num_entries;
   table->entries     = malloc(num_entries * sizeof(table->entries[0]));
@@ -130,7 +135,7 @@ tt_free(Transposition_table *table)
 }
 
 
-/* Set result and move. Return value:
+/* Get result and move. Return value:
  *   0 if not found
  *   1 if found, but depth too small to be trusted.  In this case the move
  *     can be used for move ordering.
@@ -291,6 +296,12 @@ reading_cache_clear()
   tt_clear(&ttable);
 }
 
+float
+reading_cache_default_size()
+{
+  return DEFAULT_NUMBER_OF_CACHE_ENTRIES * sizeof(Hashentry) / 1024.0 / 1024.0;
+}
+
 
 /* Write reading trace data to an SGF file. Normally called through the
  * macro SGFTRACE in cache.h.
