@@ -2,7 +2,7 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004 and 2005             *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
@@ -59,22 +59,6 @@
  */
 #define NOT_COMPUTED (-2.0 * MAX_BOARD * MAX_BOARD)
 
-/* Territory, moyo, and area are segmented into connected components
- * and given a number from the same series. These values are used in
- * region_type[].
- */
-#define WHITE_REGION    0
-#define BLACK_REGION    1
-#define IS_TERRITORY    2
-#define IS_MOYO         4
-#define IS_AREA         8
-#define WHITE_TERRI     (WHITE_REGION | IS_TERRITORY)
-#define BLACK_TERRI     (BLACK_REGION | IS_TERRITORY)
-#define WHITE_MOYO      (WHITE_REGION | IS_MOYO)
-#define BLACK_MOYO      (BLACK_REGION | IS_MOYO)
-#define WHITE_AREA      (WHITE_REGION | IS_AREA)
-#define BLACK_AREA      (BLACK_REGION | IS_AREA)
-
 /* Maximum number of regions allowed between territory, moyo, and area.
  * FIXME: This number is vastly exaggerated. Should be possible to
  * come up with a much better upper bound.
@@ -104,14 +88,6 @@ struct influence_data
   float white_permeability[BOARDMAX];
   float black_permeability[BOARDMAX];
 
-  int territory_segmentation[BOARDMAX];
-  int moyo_segmentation[BOARDMAX];
-  int area_segmentation[BOARDMAX];
-  int region_type[MAX_REGIONS];
-  int region_size[MAX_REGIONS];
-  float region_territorial_value[MAX_REGIONS];
-  int number_of_regions;
-
   int is_territorial_influence; /* 0 only if computing escape_influence.*/
 
   float territory_value[BOARDMAX];
