@@ -2,7 +2,7 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004 and 2005             *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
@@ -50,19 +50,11 @@ void clearstats(void);
 
 void transformation_init(void);
 
-void report_worm(int pos);
 void ascii_report_worm(char *string);
 void report_dragon(FILE *outfile, int pos);
 void ascii_report_dragon(char *string);
 struct dragon_data2 *dragon2_func(int pos);
 
-/* prototypes for reorientation functions */
-
-void rotate2(int i, int j, int *ri, int *rj, int rot);
-void inv_rotate2(int i, int j, int *ri, int *rj, int rot);
-int rotate1(int pos, int rot);
-int inv_rotate1(int pos, int rot);
-
 /* Routine names used by persistent and non-persistent caching schemes. */
 enum routine_id {
   OWL_ATTACK,
@@ -204,6 +196,7 @@ void dfa_match_init(void);
 
 void reading_cache_init(int bytes);
 void reading_cache_clear(void);
+float reading_cache_default_size(void);
 
 /* reading.c */
 int attack(int str, int *move);
@@ -303,9 +296,7 @@ void set_depth_values(int level, int report_levels);
 void modify_depth_values(int n);
 void increase_depth_values(void);
 void decrease_depth_values(void);
-void set_temporary_depth_values(int d, int b, int b2, int bc,
-				int ss, int br, int f, int k);
-void restore_depth_values(void);
+int get_depth_modification(void);
 
 int safe_move(int move, int color);
 int does_secure(int color, int move, int pos);
@@ -315,6 +306,7 @@ void join_dragons(int d1, int d2);
 int dragon_escape(signed char goal[BOARDMAX], int color,
 		  signed char escape_value[BOARDMAX]);
 void compute_refined_dragon_weaknesses(void);
+void compute_strategic_sizes(void);
 
 struct eyevalue;
 void compute_dragon_genus(int d, struct eyevalue *genus, int eye_to_exclude);
@@ -336,7 +328,6 @@ void get_lively_stones(int color, signed char safe_stones[BOARDMAX]);
 int is_same_worm(int w1, int w2);
 int is_worm_origin(int w, int pos);
 void propagate_worm(int pos);
-void transform2(int i, int j, int *ti, int *tj, int trans);
 void find_cuts(void);
 void find_connections(void);
 
@@ -509,9 +500,10 @@ void owl_analyze_semeai_after_move(int move, int color, int apos, int bpos,
 				   int *semeai_result_certain,
 				   int recompute_dragons);
 
+void set_limit_search(int value);
 void set_search_diamond(int pos);
 void reset_search_mask(void);
-void set_search_limit(int pos, int value);
+void set_search_mask(int pos, int value);
 int oracle_play_move(int pos, int color);
 void consult_oracle(int color);
 void summon_oracle(void);
@@ -540,10 +532,12 @@ int does_defend(int move, int str);
 int double_atari(int move, int color, float *value,
 		 signed char safe_stones[BOARDMAX]);
 int send_two_return_one(int move, int color);
+int playing_into_snapback(int move, int color);
 int play_attack_defend_n(int color, int do_attack, int num_moves, ...);
 int play_attack_defend2_n(int color, int do_attack, int num_moves, ...);
 int play_break_through_n(int color, int num_moves, ...);
 int play_connect_n(int color, int do_connect, int num_moves, ...);
+int play_lib_n(int color, int num_moves, ...);
 int cut_possible(int pos, int color);
 int defend_against(int move, int color, int apos);
 int somewhere(int color, int check_alive, int num_moves, ...);
@@ -632,17 +626,12 @@ void store_delta_territory_cache(int pos, int color, float move_value,
 			         Hash_data safety_hash);
 
 int whose_territory(const struct influence_data *q, int pos);
-int whose_loose_territory(const struct influence_data *q, int pos);
 int whose_moyo(const struct influence_data *q, int pos);
+int whose_moyo_restricted(const struct influence_data *q, int pos);
 int whose_area(const struct influence_data *q, int pos);
 float influence_territory(const struct influence_data *q, int pos, int color);
-void influence_get_moyo_segmentation(const struct influence_data *q,
-	       			     struct moyo_data *moyo);
-void influence_get_territory_segmentation(const struct influence_data *q,
+void influence_get_territory_segmentation(struct influence_data *q,
 	       			          struct moyo_data *moyo);
-void influence_get_moyo_data(const struct influence_data *q,
-			     int moyo_color[BOARDMAX],
-			     float territory_value[BOARDMAX]);
 void get_influence(const struct influence_data *q,
 		   float white_influence[BOARDMAX],
 		   float black_influence[BOARDMAX],
@@ -655,9 +644,8 @@ void get_influence(const struct influence_data *q,
 		   float territory_value[BOARDMAX],
 		   int influence_regions[BOARDMAX],
 		   int non_territory[BOARDMAX]);
-float influence_score(const struct influence_data *q);
+float influence_score(const struct influence_data *q, int chinese_rules);
 float game_status(int color);
-void resegment_initial_influence(void);
 void influence_mark_non_territory(int pos, int color);
 int influence_considered_lively(const struct influence_data *q, int pos);
 void influence_erase_territory(struct influence_data *q, int pos, int color);
@@ -731,9 +719,6 @@ extern int connect_depth2;
 extern int connection_node_limit;
 extern int breakin_depth;
 extern int breakin_node_limit;
-extern int level;               /* controls the strength of play */
-extern int min_level;           /* minimum level for adjustment schemes */
-extern int max_level;           /* minimum level for adjustment schemes */
 extern int semeai_variations;   /* max variations considered reading semeai */
 extern float best_move_values[10];
 extern int best_moves[10];
@@ -750,10 +735,6 @@ extern int large_scale;              /* seek large scale captures */
 extern int thrashing_dragon;        /* Dead opponent's dragon trying to live */
 extern signed char thrashing_stone[BOARDMAX];       /* All thrashing stones. */
 
-/* Experimental reading */
-extern char *rgoal;
-extern int goallib;
-
 extern int transformation[MAX_OFFSET][8];
 extern const int transformation2[8][2][2];
 
@@ -897,6 +878,7 @@ struct dragon_data2 {
   enum dragon_status safety;          /* a more detailed status estimate     */
   float weakness; /* A new (3.4) continuous estimate of the dragon's safety  */
   float weakness_pre_owl;     /* Dragon safety based on pre-owl computations */
+  float strategic_size; /* An effective size including weakness of neighbors */
   int escape_route; /* a measurement of likelihood of escape                 */
   struct eyevalue genus;    /* the number of eyes (approximately)            */
   int heye;     /* coordinates of a half eye                                 */
@@ -906,9 +888,11 @@ struct dragon_data2 {
   int surround_size;           /* Size of the surrounding area               */
 
   int semeais;         /* number of semeais in which the dragon is involved  */
+  int semeai_defense_code ;/* Result code for semeai defense.                */
   int semeai_defense_point;/* Move found by semeai code to rescue dragon     */
   int semeai_defense_certain;
   int semeai_defense_target; /* The opponent dragon involved in the semeai   */
+  int semeai_attack_code ; /* Result code for semeai attack.                 */
   int semeai_attack_point; /* Move found by semeai code to kill dragon       */
   int semeai_attack_certain;
   int semeai_attack_target; /* The opponent dragon involved in the semeai    */
@@ -917,6 +901,7 @@ struct dragon_data2 {
   int owl_attack_point;    /* vital point for attack                         */
   int owl_attack_code;     /* ko result code                                 */
   int owl_attack_certain;  /* 0 if owl reading node limit is reached         */
+  int owl_attack_node_count;
   int owl_second_attack_point;/* if attacker gets both attack points, wins   */
   int owl_defense_point;   /* vital point for defense                        */
   int owl_defense_code;    /* ko result code                                 */
@@ -946,8 +931,6 @@ extern float white_score, black_score;
 
 /* Global variables to tune strategy. */
 
-extern int use_optimistic_territory;
-
 extern float minimum_value_weight;
 extern float maximum_value_weight;
 extern float invasion_malus_weight;
