@@ -2,7 +2,7 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004 and 2005             *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
@@ -286,17 +286,6 @@ prepare_for_match(int color)
 }
 
 
-/* Functional version for completeness. Prefer the TRANSFORM2 macro
- * in liberty.h.
- */
-
-void 
-transform2(int i, int j, int *ti, int *tj, int trans)
-{
-  TRANSFORM2(i, j, ti, tj, trans);
-}
-
-
 /*
  * Try all the patterns in the given array at (anchor). Invoke the
  * callback for any that matches. Classes X,O,x,o are checked here. It
