@@ -2,7 +2,7 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004 and 2005             *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
@@ -362,8 +362,6 @@ add_move_reason(int pos, int type, int what)
   if (stackp == 0) {
     ASSERT1(board[pos] == EMPTY, pos);
   }
-  if (limit_search && !within_search_area(pos))
-    return;
 
   for (k = 0; k < MAX_REASONS; k++) {
     int r = move[pos].reason[k];
@@ -1637,7 +1635,8 @@ mark_safe_stones(int color, int move_pos,
     else
       safe_stones[pos] = 0;
   }
-  safe_stones[move_pos] = move[move_pos].move_safety;
+  safe_stones[move_pos]
+    = move[move_pos].move_safety && safe_move(move_pos, color) == WIN;
 }
 
 
