@@ -2,7 +2,7 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004 and 2005             *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
@@ -342,7 +342,7 @@ static int
 do_metamachine_genmove(int color, int width, float *value);
 
 int
-metamachine_genmove(int color, float *value)
+metamachine_genmove(int color, float *value, int limit_search)
 {
   int move;
   int pos;
