@@ -2,7 +2,7 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004 and 2005             *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
@@ -233,10 +233,6 @@ shapes_callback(int anchor, int color, struct pattern *pattern, int ll,
   /* Pick up the location of the move */
   move = AFFINE_TRANSFORM(pattern->move_offset, ll, anchor);
 
-  /* For restricted search, the pattern must intersect the search area */
-  if (limit_search && !within_search_area(move))
-    return;
-
   /* For some classes of patterns we need to find all dragons present
    * in the pattern.
    */
@@ -538,10 +534,6 @@ joseki_callback(int move, int color, struct corner_pattern *pattern,
   int your_dragons[MAX_DRAGONS_PER_PATTERN];
   int your_ndragons = 0;
 
-  /* For restricted search, the pattern must intersect the search area. */
-  if (limit_search && !within_search_area(move))
-    return;
-
   /* For urgent joseki patterns we need to find all dragons present in the
    * pattern since such patterns are assumed to have strategical effect on
    * them.
