@@ -2,7 +2,7 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004 and 2005             *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
@@ -57,7 +57,7 @@ play_gmp(Gameinfo *gameinfo, int simplified)
     mycolor = 0;
 
   sgftree_clear(&sgftree);
-  sgftreeCreateHeaderNode(&sgftree, board_size, komi);
+  sgftreeCreateHeaderNode(&sgftree, board_size, komi, gameinfo->handicap);
 
   ge = gmp_create(0, 1);
   TRACE("board size=%d\n", board_size);
@@ -109,7 +109,7 @@ play_gmp(Gameinfo *gameinfo, int simplified)
 
 #if ORACLE
   if (metamachine && oracle_exists)
-    oracle_clear_board(gnugo_get_boardsize());
+    oracle_clear_board(board_size);
 #endif
 
   sgfOverwritePropertyInt(sgftree.root, "SZ", board_size);
@@ -133,7 +133,7 @@ play_gmp(Gameinfo *gameinfo, int simplified)
 
   gameinfo->computer_player = mycolor;
   sgf_write_header(sgftree.root, 1, get_random_seed(), komi,
-		   level, chinese_rules);
+		   gameinfo->handicap, get_level(), chinese_rules);
   gameinfo->handicap = gnugo_sethand(gameinfo->handicap, sgftree.root);
   sgfOverwritePropertyInt(sgftree.root, "HA", gameinfo->handicap);
 
@@ -141,6 +141,7 @@ play_gmp(Gameinfo *gameinfo, int simplified)
   while (passes < 2) {
 
     if (to_move == yourcolor) {
+      int move;
       /* Get opponent's move from gmp client. */
       message = gmp_check(ge, 1, &j, &i, &error);
 
@@ -169,28 +170,31 @@ play_gmp(Gameinfo *gameinfo, int simplified)
       }
 
       if (message == gmp_pass) {
-	++passes;
-        sgftreeAddPlay(&sgftree, to_move, -1, -1);
-	gnugo_play_move(-1, -1, yourcolor);
-	sgffile_output(&sgftree);
+	passes++;
+	move = PASS_MOVE;
       }
       else {
-	/* not pass */
 	passes = 0;
-        sgftreeAddPlay(&sgftree, to_move, i, j);
-	TRACE("\nyour move: %m\n\n", i, j);
-	gnugo_play_move(i, j, yourcolor);
-	sgffile_output(&sgftree);
+	move = POS(i, j);
       }
 
+      TRACE("\nyour move: %1m\n\n", move);
+      sgftreeAddPlay(&sgftree, to_move, I(move), J(move));
+      gnugo_play_move(move, yourcolor);
+      sgffile_output(&sgftree);
+
     }
     else {
       /* Generate my next move. */
-      float move_value = gnugo_genmove(&i, &j, mycolor, NULL);
-      gnugo_play_move(i, j, mycolor);
+      float move_value;
+      int move;
+      if (autolevel_on)
+	adjust_level_offset(mycolor);
+      move = genmove(mycolor, &move_value, NULL);
+      gnugo_play_move(move, mycolor);
       sgffile_add_debuginfo(sgftree.lastnode, move_value);
       
-      if (is_pass(POS(i, j))) {
+      if (is_pass(move)) {
 	/* pass */
         sgftreeAddPlay(&sgftree, to_move, -1, -1);
 	gmp_sendPass(ge);
@@ -198,10 +202,10 @@ play_gmp(Gameinfo *gameinfo, int simplified)
       }
       else {
 	/* not pass */
-        sgftreeAddPlay(&sgftree, to_move, i, j);
-	gmp_sendMove(ge, j, i);
+        sgftreeAddPlay(&sgftree, to_move, I(move), J(move));
+	gmp_sendMove(ge, J(move), I(move));
 	passes = 0;
-	TRACE("\nmy move: %m\n\n", i, j);
+	TRACE("\nmy move: %1m\n\n", move);
       }
       sgffile_add_debuginfo(sgftree.lastnode, 0.0);
       sgffile_output(&sgftree);
