@@ -2,7 +2,7 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004 and 2005             *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
@@ -272,7 +272,6 @@ static struct autohelper_func autohelper_functions[] = {
   {"lib2",			1, 0, 0.01, "worm[%s].liberties2"},
   {"lib3",			1, 0, 0.01, "worm[%s].liberties3"},
   {"lib4",			1, 0, 0.01, "worm[%s].liberties4"},
-  {"goallib",			0, 0, 0.01, "goallib"},
   {"lib",			1, 0, 0.01, "countlib(%s)"},
   {"alive",			1, 0, 0.01,
 		"(dragon[%s].status == ALIVE)"},
@@ -357,6 +356,9 @@ static struct autohelper_func autohelper_functions[] = {
   {"oplay_disconnect",		2, 1, 10.00, "play_connect_n(color, 0, %d"},
   {"xplay_disconnect",		2, 1, 10.00,
 		"play_connect_n(OTHER_COLOR(color), 0, %d"},
+  {"oplay_lib",	        	1, 1, 0.06, "play_lib_n(color, %d"},
+  {"xplay_lib",  		1, 1, 0.06,
+                "play_lib_n(OTHER_COLOR(color), %d"},
   {"seki_helper",		1, 0, 0.0, "seki_helper(%s)"},
   {"threaten_to_save",		1, 0, 0.0, "threaten_to_save_helper(move,%s)"},
   {"threaten_to_capture",	1, 0, 0.0,
@@ -453,7 +455,7 @@ dummyhelper(int transformation, int move, int color, int action)
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *\n\
  * http://www.gnu.org/software/gnugo/ for more information.          *\n\
  *                                                                   *\n\
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004 and 2005             *\n\
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *\n\
  * by the Free Software Foundation.                                  *\n\
  *                                                                   *\n\
  * This program is free software; you can redistribute it and/or     *\n\
@@ -1967,7 +1969,8 @@ corner_best_element(struct corner_element *el, int n,
 
 /* Dynamically allocates a new variation structure. */
 static struct corner_variation_b *
-corner_variation_new(int move_offset, signed char xor_att, unsigned char num_stones)
+corner_variation_new(int move_offset, signed char xor_att,
+		     unsigned char num_stones)
 {
   struct corner_variation_b *variation;
    
