@@ -2,7 +2,7 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004 and 2005             *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
@@ -528,12 +528,15 @@ set_random_seed(unsigned int seed)
   gg_srand(seed);
 }
 
-/* Update the random seed with the current value in the random sequence.
- * This should be called at the start of each new game.
+/* Update the random seed. This should be called at the start of each
+ * new game.
+ * We reset the random seed before obtaining a new one, to make the
+ * next random seed depend deterministically on the old one.
  */
 void
 update_random_seed(void)
 {
+  gg_srand(random_seed);
   random_seed = gg_rand();
   /* Since random seed 0 has a special interpretation when given as
    * command line argument with the -r option, we make sure to avoid
